"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useEvent = exports.sendEvent = void 0;
var react_1 = require("react");
var uuid_1 = require("primeobjects-helper-util/build/cjs/uuid");
var core_1 = require("primeobjects-helper-util/build/cjs/core");
var core_2 = require("primeobjects-helper-util/build/cjs/core");
var SOURCE = "PO-USE-EVENT";
var sendEvent = function (channel, value, settings) {
    if ((0, core_1.isSSR)())
        return console.error("Require window object.");
    var expireMinutes = settings === null || settings === void 0 ? void 0 : settings.expireMinutes;
    var senderName = settings === null || settings === void 0 ? void 0 : settings.senderName;
    (0, core_2.setCache)(channel, { value: value, senderName: senderName, id: (0, uuid_1.newGuid)() }, expireMinutes);
    (0, core_1.getWindow)().postMessage({ source: SOURCE, channel: channel });
};
exports.sendEvent = sendEvent;
var useEvent = function (channel) {
    var data = (0, core_2.getCache)(channel);
    var _a = (0, react_1.useState)(""), valueRefreshed = _a[0], setValuedRefreshed = _a[1];
    var SSR = (0, core_1.isSSR)();
    (0, core_2.doNothing)(valueRefreshed);
    var messageHandler = function (message) {
        var data = message.data;
        if (data.source == SOURCE && data.channel == channel) {
            setValuedRefreshed((0, uuid_1.newGuid)());
        }
    };
    (0, react_1.useEffect)(function () {
        var win = (0, core_1.getWindow)();
        if (SSR) {
            console.error("Require window object.");
        }
        else {
            if (win.addEventListener) {
                win.addEventListener("message", messageHandler);
            }
            else {
                win.attachEvent("onmessage", messageHandler);
            }
        }
        return function () {
            if (win.removeEventListener)
                win.removeEventListener("message", messageHandler);
            if (win.detachEvent)
                win.detachEvent("onmessage", messageHandler);
        };
    }, [SSR]);
    return [data === null || data === void 0 ? void 0 : data.value, data === null || data === void 0 ? void 0 : data.id];
};
exports.useEvent = useEvent;
//# sourceMappingURL=use-event.js.map